# Filters

This module contains all filter methods that are available to use on Stream objects as well as functions for using source filters.

::: pyffmpeg.generated_filters.GeneratedFiltersMixin
    options:
      show_root_heading: true
      show_source: true

::: pyffmpeg.sources
    options:
      show_root_heading: true
      show_source: true